API Documentation — PodGen Documentation

# API Documentation

`podgen.Podcast`(**kwargs) | Class representing one podcast feed.
`podgen.Episode`(**kwargs) | Class representing an episode in a podcast.
`podgen.Person`([name, email]) | Data-oriented class representing a single person or entity.
`podgen.Media`(url[, size, type, duration, ...]) | Data-oriented class representing a pointer to a media file.
`podgen.Category`(category[, subcategory]) | Immutable class representing an iTunes category.
`podgen.util` | podgen.util